#! /usr/bin/env python
# -*- coding: utf-8 -*_
# Author: Yunlong Feng <ylfeng@ir.hit.edu.cn>

requirements = [
    "pytorch_lightning",
    "datasets",
]
